@@ -14,9 +14,10 @@ HCLclustering <-function(Data,ClusterNo,PlotIt=FALSE,...){
 
   requireNamespace('cclust')
   res=cclust::cclust(x=Data,centers=ClusterNo,method='hardcl',...)
+  Cls=res$cluster
   if(PlotIt){
-    requireNamespace('DataVisualizations')
-    DataVisualizations::Plot3D(Data,res$cluster)
+   ClusterPlotMDS(Data,Cls)
   }
-  return(list(Cls=res$cluster,Object=res))
+   Cls=ClusterRename(Cls,Data)
+  return(list(Cls=Cls,Object=res))
 }
\ No newline at end of file
