@@ -19,8 +19,8 @@ LargeApplicationClustering <-function(Data,ClusterNo,PlotIt=FALSE,Standardizatio
   Cls=res$clustering
 
   if(PlotIt){
-    requireNamespace('DataVisualizations')
-    DataVisualizations::Plot3D(Data,Cls)
+    ClusterPlotMDS(Data,Cls)
   }
+  	Cls=ClusterRename(Cls,Data)
   return(list(Cls=Cls,Object=res))
 }
\ No newline at end of file
