@@ -37,7 +37,9 @@ MinimalEnergyClustering <-function(DataOrDistances,ClusterNo=0,DistanceMethod="e
 	
 # Classification or Dendrogram
 	if (ClusterNo>0){
-		return (cutree(hc,ClusterNo));
+		Cls=cutree(hc,ClusterNo)
+		Cls=ClusterRename(Cls,DataOrDistances)
+		return (Cls)
 	} 
 	else{
 		x=as.dendrogram(hc);plot(x, main=m,xlab="Number of Data Points N", ylab="Distance",sub=" ",leaflab ="none",...)
