@@ -2,16 +2,16 @@ OPTICSclustering=function(Data, MaxRadius,RadiusThreshold, minPts = 5, PlotIt=FA
   
   requireNamespace('dbscan')
   
-  if(missing(MaxRadius)){  
+  if(is.null(MaxRadius)){  
     warning('The MaxRadius (eps) parameter is missing but it is required in OPTICS Trying to estimate..')
 	requireNamespace('DataVisualizations')
     MaxRadius=0.5*DataVisualizations::ParetoRadius(Data)
   } 
-  if(missing(RadiusThreshold)){  
+  if(is.null(RadiusThreshold)){  
     warning('The RadiusThreshold (eps_cl) parameter is missing but it is required in OPTICS Trying to estimate..')
     RadiusThreshold=0.9*MaxRadius
   } 
-  if(missing(minPts)){
+  if(is.null(minPts)){
     minPts=round(0.025*nrow(Data),0)
     warning('The minPts parameter is missing but it is required in DBscan. Trying to estimate..')
   }  
@@ -25,8 +25,8 @@ OPTICSclustering=function(Data, MaxRadius,RadiusThreshold, minPts = 5, PlotIt=FA
   }
   
   if(PlotIt){
-    requireNamespace('DataVisualizations')
-    DataVisualizations::Plot3D(Data,Cls)
+    ClusterPlotMDS(Data,Cls)
   }
+	Cls=ClusterRename(Cls,Data)
   return(list(Cls=Cls,Object=OPTICScobject))
 }
\ No newline at end of file
